@@ -1,5 +1,4 @@
 import argparse
-import hashlib
 import json
 from collections import defaultdict
 from datetime import datetime
@@ -8,7 +7,7 @@ from pathlib import Path
 import pandas as pd
 import plotly.express as px
 
-__version__ = "0.0.4"
+__version__ = "0.0.5"
 
 
 class Runtime:
@@ -23,22 +22,17 @@ class Runtime:
         return {"rule": self.rule, "stime": self.stime, "etime": self.etime, "cost": self.cost}
 
 
-def get_md5sum(file):
-    with open(file, "rb") as f:
-        return hashlib.md5(f.read()).hexdigest()
-
-
 def get_runtimes(metadata: str, min_seconds: int = None, sort_by_name: bool = False) -> pd.DataFrame:
     metadata = Path(metadata)
     counter = defaultdict(int)
     dataset = set()
     runtimes = []
     for p in metadata.iterdir():
-        md5sum = get_md5sum(p)
-        if md5sum not in dataset:
-            dataset.add(md5sum)
-            with p.open() as f:
-                data = json.load(f)
+        with p.open() as f:
+            data = json.load(f)
+            job_hash = data["job_hash"]
+            if job_hash not in dataset:
+                dataset.add(job_hash)
                 rule = data["rule"]
                 stime = datetime.fromtimestamp(data["starttime"])
                 etime = datetime.fromtimestamp(data["endtime"])
